pub enum Error {
PreferenceTypeNumber(String),
PreferenceTypeBool(String),
PreferenceTypeString(String),
PreferenceTypeStringList(String),
PreferenceTypeJsonValue(String),
Core(Error),
}Expand description
Errors generated by the library.
Variants
PreferenceTypeNumber(String)
Error generated when a preference is not a number.
PreferenceTypeBool(String)
Error generated when a preference is not a boolean.
PreferenceTypeString(String)
Error generated when a preference is not a string.
PreferenceTypeStringList(String)
Error generated when a preference is not a string list.
PreferenceTypeJsonValue(String)
Error generated when a preference is not a JSON value.
Core(Error)
Errors generated by the core library.